Cleanup/wg init (#260)

* remove wg_init and wg_finalize from functional tests

* Remove wg_init and wg_finalize from examples

* deprecate wg_init/finalize

* Updated docs

* Typo in documentation

---------

Co-authored-by: Yiltan <yiltan@amd.com>

[ROCm/rocshmem commit: 6e7277b544]
This commit is contained in:
Aurelien Bouteiller
2025-10-07 14:34:18 -04:00
committed by GitHub
parent 192c549d40
commit 8837414042
32 changed files with 23 additions and 68 deletions
@@ -374,7 +374,7 @@ __host__ void rocshmem_global_exit(int status);
*
* @return void.
*/
__device__ void rocshmem_wg_init();
[[deprecated]] __device__ void rocshmem_wg_init();
/**
* @brief Finalizes device-side rocSHMEM resources. Must be called before
@@ -384,7 +384,7 @@ __device__ void rocshmem_wg_init();
*
* @return void.
*/
__device__ void rocshmem_wg_finalize();
[[deprecated]] __device__ void rocshmem_wg_finalize();
/**
* @brief Initializes device-side rocSHMEM resources. Must be called before
@@ -400,7 +400,7 @@ __device__ void rocshmem_wg_finalize();
*
* @return void.
*/
__device__ void rocshmem_wg_init_thread(int requested, int *provided);
[[deprecated]] __device__ void rocshmem_wg_init_thread(int requested, int *provided);
/**
* @brief Query the thread mode used by the runtime.